@@ -3,7 +3,7 @@ package App::FirefoxMultiAccountContainersUtils;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-05-25'; # DATE
 our $DIST = 'App-FirefoxMultiAccountContainersUtils'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -81,7 +81,7 @@ sub firefox_mua_sort_containers {
     }
     return [404, "No such Firefox profile '$args{profile}', ".
                 "available profiles include: ".
-                join(", ", map {$_->{path}} @{$res->[2]})]
+                join(", ", map {$_->{name}} @{$res->[2]})]
         unless defined $path;
 
     $path = "$path/containers.json";
@@ -129,7 +129,7 @@ App::FirefoxMultiAccountContainersUtils - Utilities related to Firefox Multi-Acc
 
 =head1 VERSION
 
-This document describes version 0.002 of App::FirefoxMultiAccountContainersUtils (from Perl distribution App-FirefoxMultiAccountContainersUtils), released on 2020-05-25.
+This document describes version 0.003 of App::FirefoxMultiAccountContainersUtils (from Perl distribution App-FirefoxMultiAccountContainersUtils), released on 2020-05-25.
 
 =head1 SYNOPSIS
 
